/*
	File:		EntryPoints.h

	Contains:	This file contains misc. items for the EntryPoints.c file
	Written by:	

	Copyright:	 1993-1996 by Apple Computer, Inc., all rights reserved.

	Change History (most recent first):

	   <FW7>	12/27/96	ES		Changed a bunch of "FWDriver"s to "FWClient"s. Changed to
									protocol driver.
	   <FW6>	12/16/96	ES		Changed to work with new read/write/lock request/complete
									processing mechanism.
	   <FW5>	 9/16/96	ES		Changed FireWire driver interface procs to return command
									acceptance.
	   <FW4>	 8/29/96	ES		Changed FWDriverInterface to FWDriverWriteRequestInterface.
	   <FW3>	 6/20/96	ES		Made this look more like a .i generated interface.
	   <FW2>	 4/15/96	ES		Update for use with Driver Notification services.
	   <FW1>	 3/27/96	ES		first checked in

	To Do:
*/

#ifndef __ENTRYPOINTS__
#define __ENTRYPOINTS__

#ifndef __FIREWIRE__
#include <FireWire.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

//-----------------------------------------------------------------------------------------
//	Function Prototypes
//-----------------------------------------------------------------------------------------

void EnqueueElementAtHead(QHdr *theQHdr, QElem *theElem, UInt16 whichIntsOff);
void EnqueueElement(QHdr *theQHdr, QElem *theElem, UInt16 whichIntsOff);
QElem *DequeueHead(QHdr *theHdr, UInt16 whichIntsOff);
QElem *DequeueElement(QHdr *theQHdr, QElem *theElem, UInt16 whichIntsOff);

OTResult ValidateHardware(RegEntryID *theID);
Boolean	InitStreamModule(RegEntryID *theID);
void TerminateStreamModule(void);
OSErr InitCFMRoutine(CFragInitBlock *theInitBlock);
void TerminateCFMRoutine(void);
install_info* GetOTInstallInfo(void);

int OpenServiceRoutine(queue_t *q, dev_t *, int, int, cred_t *);
int CloseServiceRoutine(queue_t *q, int, cred_t *);
int WritePutRoutine(queue_t *q, mblk_t *mp);
int WriteServiceRoutine(queue_t *q);

void IOCtlTheStream(queue_t *, mblk_t *);
void FlushTheStream(queue_t *, mblk_t *);
UInt16 GenerateUniqueMinorDevice(void);
Boolean CheckThisMinorDevice(UInt16 minorDeviceNumber);
void AttemptPacketSend(void);
void PreparePacketToBeSent(mblk_t *thePacket);

pascal void RxDTCallback(void *theParam);
pascal void TxDTCallback(void *theParam);
void HandleTimerMessages(queue_t *writeQueue, mblk_t *mp);



Boolean OTInitModule(void);
void OTTerminateModule(void);

OSStatus	FWClientWriteCompleteInterface (
	FWClientAsynchRequestParamsPtr
								pFWClientAsynchRequestParams,
	UInt32						*pCommandAcceptance);

OSStatus	FWPDriverUnitAdded (
	FWPDriverID					fwPDriverID,
	UInt32						fwPDriverSpecificData,
	FWDriverID					fwUnitID);

OSStatus	FWPDriverUnitRemoved (
	FWPDriverID					fwPDriverID,
	UInt32						fwPDriverSpecificData,
	FWDriverID					fwUnitID);

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __ENTRYPOINTS__ */
